@@ -15,8 +15,6 @@
 # limitations under the License.
 #
 
-import warnings
-
 from h2o.utils.typechecks import assert_is_type
 from pyspark.ml.param import *
 
@@ -56,6 +54,12 @@ class H2OCommonParams(H2OMOJOAlgoSharedParams):
         "Number of fold columns",
         H2OTypeConverters.toInt())
 
+    allStringColumnsToCategorical = Param(
+        Params._dummy(),
+        "allStringColumnsToCategorical",
+        "Transform all strings columns to categorical",
+        H2OTypeConverters.toBoolean())
+
     columnsToCategorical = Param(
         Params._dummy(),
         "columnsToCategorical",
@@ -81,9 +85,7 @@ class H2OCommonParams(H2OMOJOAlgoSharedParams):
         return self.getOrDefault(self.nfolds)
 
     def getAllStringColumnsToCategorical(self):
-        warnings.warn("The 'getAllStringColumnsToCategorical' method has been deprecated without replacement."
-                      "The method will be removed in the version 3.32.", DeprecationWarning)
-        return False
+        return self.getOrDefault(self.allStringColumnsToCategorical)
 
     def getColumnsToCategorical(self):
         return self.getOrDefault(self.columnsToCategorical)
@@ -107,9 +109,7 @@ class H2OCommonParams(H2OMOJOAlgoSharedParams):
         return self._set(nfolds=value)
 
     def setAllStringColumnsToCategorical(self, value):
-        warnings.warn("The 'setAllStringColumnsToCategorical' method has been deprecated without replacement."
-                      "The method will be removed in the version 3.32.", DeprecationWarning)
-        return self
+        return self._set(allStringColumnsToCategorical=value)
 
     def setColumnsToCategorical(self, value, *args):
         assert_is_type(value, [str], str)
@@ -145,6 +145,3 @@ class H2OCommonParams(H2OMOJOAlgoSharedParams):
 
     def setNamedMojoOutputColumns(self, value):
         return self._set(namedMojoOutputColumns=value)
-
-    def setWithContributions(self, value):
-        return self._set(withContributions=value)
